@@ -4,7 +4,7 @@
 tmdbsimple.configuration
 ~~~~~~~~~~~~~~~~~~~~~~~~
 
-This module implements the Configuration, Certifications, and Timezones 
+This module implements the Configuration, Certifications, and Timezones
 functionality of tmdbsimple.
 
 Created by Celia Oakley on 2013-10-31.
@@ -34,7 +34,24 @@ class Configuration(TMDB):
 
     def info(self, **kwargs):
         """
-        Get the system wide configuration info.
+        Get the system wide configuration information. Some elements of the API
+        require some knowledge of this configuration data. The purpose of this
+        is to try and keep the actual API responses as light as possible. It is
+        recommended you cache this data within your application and check for
+        updates every few days.
+
+        This method currently holds the data relevant to building image URLs as
+        well as the change key map.
+
+        To build an image URL, you will need 3 pieces of data. The base_url,
+        size and file_path. Simply combine them all and you will have a fully
+        qualified URL. Here’s an example URL:
+
+            https://image.tmdb.org/t/p/w500/8uO0gUM8aNqYLs1OsTBQiXu0fEv.jpg
+
+        The configuration method also contains the list of change keys which
+        can be useful if you are building an app that consumes data from the
+        change feed.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -188,4 +205,3 @@ class Timezones(TMDB):
         response = self._GET(path, kwargs)
         self._set_attrs_to_values(response)
         return response
-
